# Presence Sensor Project with ESP32-S3 Board and mmWave

ESPHome configuration for the HMMD mmWave Sensor S3KM1110 on an ESP32-S3 board.

> **Tested with:** ESPHome version 2025.2.2

## Features

- MQTT integration for Home Assistant
- Optional native Home Assistant API (disabled by default)
- Status LED via WS2812
- WiFi fallback Access Point
- Easy customization via `secrets_template.yaml`

## Getting Started

### 1. Prepare secrets.yaml

Copy the template and add your details:

```bash
cp secrets_template.yaml secrets.yaml
```

### 2. Adjust device name (optional)

Change the device name and friendly name at the top of the YAML:

```yaml
substitutions:
  device_name: presence_sensor
  friendly_name: "Presence Sensor"
```

### 3. Flash your ESP32-S3

Use ESPHome CLI or Home Assistant ESPHome Add-On.

### 4. Optional: Enable Home Assistant API

Uncomment the `api:` section and provide the API encryption key in `secrets.yaml` if you prefer native API over MQTT.

```yaml
# api:
#   encryption:
#     key: !secret api_encryption_key
```

### 5. Add to Home Assistant

If using MQTT with discovery enabled, your device will appear automatically.

## Hardware

This configuration was tested with the following hardware:

- ✅ HMMD mmWave Sensor (S3KM1110)
  - [Amazon Link](https://www.amazon.de/gp/aw/d/B0CT8JTMJM)
  - [Waveshare Wiki](https://www.waveshare.com/wiki/HMMD_mmWave_Sensor)

- ✅ ESP32-S3 board (Waveshare ESP32-S3 Zero)
  - [Amazon Link](https://www.amazon.de/Waveshare-Development-ESP32-S3FH4R2-Castellated-Applications/dp/B0CHYHGYRH?th=1&psc=1)
  - [Waveshare Wiki](https://www.waveshare.com/wiki/ESP32-S3-Zero)

**Wiring:**

- ESP32-S3 TX (GPIO7) → Sensor RX
- ESP32-S3 RX (GPIO6) → Sensor TX
- Sensor VCC → 3.3V on ESP32-S3
- Sensor GND → GND on ESP32-S3
- WS2812 LED Data → GPIO21 on ESP32-S3
